!* +-----------------------------------------------------------------------
!* | WHAT TEXTURE?
!* | Function to classify a soil in the triangle based on sand and clay %
!* +-----------------------------------------------------------------------
!* | Created by: aris gerakis, apr. 98
!* | Modified by: aris gerakis, june 99.  Now check all polygons instead of
!* | stopping when a right solution is found.  This to cover all borderline
!* | cases.
!* | Modified by: aris gerakis, feb. 2001:  Portuguese triangle.
!* | Modified by: aris gerakis, mar. 2011:  Fixed bug in Portuguese triangle.
!* +-----------------------------------------------------------------------

character*42 function what_texture (sand, clay)

implicit none

! Declare arguments:

real, intent(in) :: clay, sand

! Declare local variables:

logical   :: inpoly
real      :: arenoso(7,2), arenoso_franco(7,2), franco_arenoso(7,2), franco(7,2), &
             limoso(7,2), franco_limoso(7,2), franco_argilo_limoso(7,2), &
             franco_argilo_arenoso(7,2), franco_argiloso(7,2), argilo_arenoso(7,2), argilo_limoso(7,2), &
             argiloso(7,2)
character :: texture*42

!Initalize polygon coordinates:
! First write all x's, pad with 0s if less than 7 vertices, then
! write all y's, pad with 0s if less than 7 vertices:

data arenoso/91, 90, 100, 0, 0, 0, 0, 0, 10, 0,0, 0,0, 0/
data arenoso_franco/83, 85, 90, 91, 0, 0, 0, 0, 15, 10,0,0, 0, 0/
data franco_arenoso/71, 64, 69, 65, 80, 85, 83, 0, 8, 8,20, 20, 15, 0/
data franco/64, 45, 57, 65, 69, 0, 0, 8, 27, 27, 20,8, 0, 0/
data limoso/0, 42, 54, 0, 0, 0, 0, 12, 12, 0,0, 0, 0, 0/
data franco_limoso/0, 0, 45, 64, 71, 54, 42, 12, 27, 27,8, 0, 0, 12/
data franco_argilo_limoso/0, 0, 37, 44, 0, 0, 0, 27, 40,40, 27, 0, 0, 0/
data franco_argilo_arenoso/65, 57, 53.74, 65, 80, 0, 0, 20,27, 35, 35, 20, 0, 0/
data franco_argiloso/44, 37, 51.71, 57, 0, 0, 0, 27, 40, 40,27, 0, 0, 0/
data argilo_arenoso/53.74, 46, 65, 0, 0, 0, 0, 35, 54, 35,0, 0, 0, 0/
data argilo_limoso/0, 0, 17, 37, 0, 0, 0, 40, 60, 60,40, 0, 0, 0/
data argiloso/0, 0, 46, 51.71, 37, 17, 0, 60, 100, 54, 40,40, 60, 0/

! Find polygon(s) where the point is.

texture = ' '

!if (sand .gt. 0.0 .and. clay .gt. 0.0) then
   if (inpoly(arenoso, 3, sand, clay)) then
      texture = trim(texture)//'/arenoso'
   endif
   if (inpoly(arenoso_franco, 4, sand, clay)) then
      texture = trim(texture)//'/arenoso franco'
   endif
   if (inpoly(franco_arenoso, 7, sand, clay)) then
      texture = trim(texture)//'/franco arenoso'
   endif
   if (inpoly(franco, 5, sand, clay)) then
      texture = trim(texture)//'/franco'
   endif
   if (inpoly(limoso, 4, sand, clay)) then
      texture = trim(texture)//'/limoso'
   endif
   if (inpoly(franco_limoso, 7, sand, clay)) then
      texture = trim(texture)//'/franco limoso'
   endif
   if (inpoly(franco_argilo_limoso, 4, sand, clay)) then
      texture = trim(texture)//'/franco argilo limoso'
   endif
   if (inpoly(franco_argilo_arenoso, 5, sand, clay)) then
      texture = trim(texture)//'/franco argilo arenoso'
   endif
   if (inpoly(franco_argiloso, 4, sand, clay)) then
      texture = trim(texture)//'/franco argiloso'
   endif
   if (inpoly(argilo_arenoso, 3, sand, clay)) then
      texture = trim(texture)//'/argilo arenoso'
   endif
   if (inpoly(argilo_limoso, 4, sand, clay)) then
      texture = trim(texture)//'/argilo limoso'
   endif
   if (inpoly(argiloso, 6, sand, clay)) then
      texture = trim(texture)//'/argiloso'
   endif
!endif

if (texture == ' ') then
   texture = '/unknown texture'
   write (unit = 6, fmt = 1000) sand, clay
   1000 format (/, 1x, 'Texture not found for ', f5.1, ' sand and ', f5.1, ' clay')
endif

what_texture = texture

return
end function what_texture
