!* +-----------------------------------------------------------------------
!* |                         T R I A N G L E
!* | Main program that calls WHAT_TEXTURE, a function that classifies soil
!* | in the USDA textural triangle using sand and clay %
!* +-----------------------------------------------------------------------
!* | Created by: aris gerakis, apr. 98 with help from brian baer
!* | Modified by: aris gerakis, july 99: now all borderline cases are valid
!* | Modified by: aris gerakis, feb. 2001:  Portuguese triangle.
!* +-----------------------------------------------------------------------
!* | COMMENTS
!* | o Supply a data file with two columns, in free format:  1st column sand,
!* |   2nd column clay %, no header.  The output is a file with the classes.
!* +-----------------------------------------------------------------------
!* | You may use, distribute and modify this code provided you maintain
!* ! this header and give appropriate credit.
!* +-----------------------------------------------------------------------

program triangle

implicit none

integer    :: flstat
real       :: sand, clay
character  :: infile*12, outfile*12, texture*42, what_texture*42
logical    :: eof

write (unit = 6, fmt = 3000)
3000 format (/, 10x, 'Classify soils in the Portuguese triangle using sand and clay %.', /, &
                10x, 'By aris gerakis, apr. 2011 with help from brian baer. Supply', /, &
                10x, 'a text (ASCII) file with two columns, in free format, no', /, &
                10x, 'header: First column sand %, second column clay %. Output', /, &
                10x, 'is text file with the textural classes. To send feedback:', /, &
                10x, 'gerakis@msu.edu.', /)

! Open input-output files:

write (unit = 6, fmt = '(10x, $a)') 'Enter input filename up to 12 characters: '
read (unit = 5, fmt = '(a)') infile
open (unit = 10, file = infile, status = 'old')
open (unit = 20, file = 'soilclas.out', status = 'unknown')

eof = .false.

do while(.not. eof)

   sand = 0.0
   clay = 0.0

   ! Read input:
   read (unit = 10, fmt = *, iostat = flstat) sand, clay

   if (flstat .eq. 0) then
      ! Call function that estimates texture:
      texture = what_texture (sand, clay)
      ! Write output:
      write (unit = 20, fmt = 2000) sand, clay, texture(2:len_trim(texture))
      2000  format (2(1x, f5.1), 1x, a)
   elseif (flstat .eq. -1) then
      eof = .true.
   else
      write (unit = 20, fmt = 1000) 
      write (unit = 6, fmt = 1000) 
      1000  format (1x, 'ERROR - please check your inputs')
   endif

enddo

write (unit = 6, fmt = '(10x, a)') 'Your output file is soilclas.out'

close (unit = 10)
close (unit = 20)

end program triangle
